# Documentation

* [Home](index.html)
* [Quick Setup](quick-setup.html)

## 🚀 For End Users

* [Quick Start Guide](quick-start-user.html)
* [Local Development](deployment/local-development.html)
* [User Dockerfile](deployment/user-dockerfile.html)
* [Cloud Platforms](deployment/cloud-platforms.html)
* [Kubernetes](deployment/kubernetes.html)

## 📖 Core Documentation

* [Configuration](configuration.html)
* [Features](features/markdown.html)
  * [Markdown Features](features/markdown.html)
  * [Navigation](features/navigation.html)
  * [Customization](features/customization.html)
  * [LLMs.txt Support](features/llms-txt.html)
  * [MCP Integration](features/mcp.html)
* [Deployment](deployment/docker.html)
  * [Docker Deployment](deployment/docker.html)
* [API Reference](api/endpoints.html)
  * [HTTP Endpoints](api/endpoints.html)
